<?php

namespace Country\Country\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Country\Country\Interfaces\CountryRepositoryInterface;
use Country\Country\Repositories\Presenter\CountryItemTransformer;

/**
 * Pubic API controller class.
 */
class CountryPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Country\Country\Interfaces\CountryRepositoryInterface $country
     *
     * @return type
     */
    public function __construct(CountryRepositoryInterface $country)
    {
        $this->repository = $country;
        parent::__construct();
    }

    /**
     * Show country's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $countries = $this->repository
            ->setPresenter('\\Country\\Country\\Repositories\\Presenter\\CountryListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $countries['code'] = 2000;
        return response()->json($countries)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show country.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $country = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($country)) {
            $country         = $this->itemPresenter($module, new CountryItemTransformer);
            $country['code'] = 2001;
            return response()->json($country)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
